/*
** Zope3 onlinehelp style sheet for CSS2-capable browsers.
**
*/

/* Basic Elements 
*/

body {
    font: 85% Helvetica, Arial, sans-serif;
    background: White;
    color: Black;
    margin: 0;
    padding: 0;
}

table {
    font-size: 85%;
}

a {
    text-decoration: none;
    color: #369;
    background-color: transparent;
}

a:active {
    text-decoration: underline;
}

img {
    border: none;
    vertical-align: middle;
}

p {
    margin: 0.5em 0em 1em 0em;
    line-height: 1.5em;
}

p a:visited {
    color: Purple;
    background-color: transparent;
}

p a:active {
    color: Red;
    background-color: transparent;
}

p img {
    border: 0;
    margin: 0;
}


hr {
    clear: both;
    height: 1px;
    color: #369;
    background-color: transparent;
}


h1, h2, h3, h4, h5, h6 {
    color: Black;
    font: 80% bold Verdana, Helvetica, Arial, sans-serif;
    margin: 0;
    padding-top: 0.5em;
    border-bottom: 1px solid #369;
}

h1 {
    font-size: 160%;
}

h2 {
    font-size: 150%;
}

h3 {
    font-size: 140%;
}

h4 {
    font-size: 120%;
}

h5 {
    font-size: 100%;
}

h6 {
    font-size: 80%;
}

ul { 
    line-height: 1.5em;
    /* list-style-image: url("bullet.gif"); */
    margin-left: 2em;
    padding:0;
}

ol {
    line-height: 1.5em;
    margin-left: 2em;
    padding:0;
}

dl {
}

dt {
    font-weight: bold;    
}

dd {
    line-height: 1.5em;
    margin-bottom: 1em;
}

abbr, acronym, .explain {
    border-bottom: 1px dotted Black;
    color: Black;
    background-color: transparent;
    cursor: help;
}

q {
    font-family: Times, "Times New Roman", serif;
    font-size: 100%;
}

blockquote {
    font-family: Times, "Times New Roman", serif;
    font-size: 100%;
}

code {
    font-family: "Courier New", Courier, monospace;
    font-size: 100%;
    color: Black;
    background-color: #FFD900;
}

pre {
    font-family: "Courier New", Courier, monospace;
    font-size: 100%;
    padding: 1em;
    border: 1px solid #A0A0A0;
    color: Black;
    background-color: #C7CDE4;
}

/*
*/

a.active {
    font-weight: bold;
}

/* layout styles
*/

.headline {
    width: 100%;
    height: 35px;
    font-size: 150%;
    color: white;
    background: #0066CC;
    border-bottom: 1px solid silver;
}
.headline div.title {
    padding: 5px 0px 0px 5px;
}

table.layout {
    font: 100% Helvetica, Arial, sans-serif;
}

table.layout td.navigation {
    vertical-align: top;
    background: #F0F0F0;
    border-right: 1px solid silver;
    border-bottom: 1px solid silver;
}

table.layout td.content {
    vertical-align: top;
    padding: 10px 5px 5px 20px;
}

div.box div.title {
    font-weight: bold;
    background: #FFD900;
    border-bottom: 1px solid silver;
    padding: 5px 0px 5px 0px;
}

div.box div.title div {
    padding: 0px 0px 0px 5px;
}
